@@ -69,6 +69,9 @@ extern int Tdp_SendToCmd		_ANSI_ARGS_((ClientData clientData,
 extern void Tdp_Tcp_Init		_ANSI_ARGS_((Tcl_Interp *interp));
 extern void Tdp_CleanupFile		_ANSI_ARGS_((Tcl_Interp *interp,
 					     char *file, int fd));
+extern int Tdp_GetPort			_ANSI_ARGS_((Tcl_Interp *interp,
+					     char *portstr, char *proto,
+					     int *portp));
 
 /* dpnetInit.c */
 extern int Tdp_networkInit		_ANSI_ARGS_((Tcl_Interp *interp));
