@@ -30,7 +30,7 @@
 #include <math.h>
 #include <limits.h>
 
-#include "tkInt.h"
+#include "tk.h"
 #include "dpInt.h"
 
 /* ---------------------------------------------------- */
@@ -1295,7 +1295,7 @@ static char *ceCmdTemplate =
     dp_RDO $rpcFile set errorInfo \"$errorInfo\n    while remotely executing\n%s\"; \
     dp_RDO $rpcFile eval \"%s \\{$dp_rv\\}\"\
 } else {\
-    dp_RDO $rpcFile eval \"%s $dp_rv\"\
+    dp_RDO $rpcFile eval \"%s \\{$dp_rv\\}\"\
 }";
 
 /*
@@ -1430,6 +1430,45 @@ Tdp_RDOCmd(unused, interp, argc, argv)
     return (result);
 }
 
+/*
+ *--------------------------------------------------------------
+ *
+ * Tdp_RDO --
+ *
+ *	This procedure is the C interface to the "RDO" command.
+ *
+ * Results:
+ *	A standard Tcl result.
+ *
+ * Side effects:
+ *	See the user documentation.
+ *
+ *--------------------------------------------------------------
+ */
+
+int
+Tdp_RDO (interp, fileHandle, command)
+    Tcl_Interp *interp;		/* Current interpreter. */
+    char *fileHandle;
+    char *command;
+{
+    int result;
+    int fd;
+    FILE *filePtr;
+
+    /*
+     * Get the file descriptor we will be using.
+     */
+    if (Tcl_GetOpenFile(interp, fileHandle, 1, 1, &filePtr) != TCL_OK) {
+	return TCL_ERROR;
+    }
+    fd = fileno(filePtr);
+
+    result = send_tagged_packet(interp, fileHandle, TOK_RDO, command);
+    ckfree((char *) command);
+    return (result);
+}
+
 /*
  *--------------------------------------------------------------
  *
