@@ -129,18 +129,20 @@ proc dp_MakeRPCClient {host port {checkCmd none}} {
     return $client
 }
 
-proc dp_MakeRPCServer {{port 0} {loginFunc dp_CheckHost} {checkCmd none}} {
-    set rv [dp_connect -server $port]
+proc dp_MakeRPCServer  {{port 0} {loginFunc dp_CheckHost} {checkCmd none}
+			{retFile 0}} {
+    set rv [dp_connect -server $port -reuseAddr]
     set server [lindex $rv 0]
-    # These next lines should make it so that a socket can be reused.
-    dp_socketOption $server linger 0
-    dp_socketOption $server reuseAddr yes
 
     set port [lindex $rv 1]
     dp_filehandler $server re "dp_AcceptRPCConnection $loginFunc $checkCmd"
     dp_atexit appendUnique "close $server"
     dp_atclose $server append "dp_ShutdownServer $server"
-    return $port
+    if $retFile {
+	return $rv
+    } else {
+	return $port
+    }
 }
 
 #
